Features for Academic Support
=============================

What makes our system different from other project management software
is academic support.  This includes allowing supervisors to evaluate
project progress and academic assistants to make statistical reports
and export transcripts for students.

.. toctree::
   :maxdepth: 2

   use-case
   database
